@@ -1,4 +1,5 @@
 from PythonExtensions.Files import *
+from PythonExtensions.debug import *
 
 
 
@@ -8,3 +9,5 @@ __all__ = ['test_files']
 def test_files():
     _file = File.TemporaryFile('PythonExtensions', name='test.txt')
     _file.Write('test data')
+
+    PrettyPrint(Path.ListDir('.'))
